@@ -3,6 +3,7 @@
 #define CORE_CORETOOLS_MATH_TMEANVARMAP_H_
 
 #include <map>
+#include "coretools/Main/TError.h"
 #include "coretools/Math/TMeanVar.h"
 
 namespace coretools {
@@ -25,9 +26,8 @@ public:
 		T sum = 0;
 		for (auto &it : _meanVar) {
 			// check for numeric under- and overflow
-			if (!checkForNumericOverflow_addition(sum, it.second.sum())) {
-				DEVERROR("Numeric under- or overflow occured!");
-			}
+			DEV_ASSERT(checkForNumericOverflow_addition(sum, it.second.sum()));
+
 			sum += it.second.sum();
 		}
 		return sum;
@@ -36,7 +36,8 @@ public:
 	bool exists(const U ID) const { return _meanVar.find(ID) != _meanVar.end(); };
 
 	const TMeanVar<T> &operator[](const U ID) {
-		if (!exists(ID)) DEVERROR("No entry with key " + str::toString(ID) + " in TMeanVarMap!");
+		DEV_ASSERT(exists(ID));
+
 		return _meanVar[ID];
 	};
 };
