@@ -15,41 +15,37 @@ private:
 	std::vector<TMeanVar<T>> _meanVar;
 
 public:
-	TMeanVarVector(){};
-	TMeanVarVector(const uint32_t Size) { _meanVar.resize(Size); };
+	TMeanVarVector() = default;
+	TMeanVarVector(size_t Size) { _meanVar.resize(Size); }
 
-	void clear() { _meanVar.clear(); };
+	void clear() { _meanVar.clear(); }
 
 	void add(const uint32_t ID, const T Value) {
 		if (_meanVar.size() <= ID) { _meanVar.resize(ID + 1); }
 		_meanVar[ID].add(Value);
-	};
+	}
 
-	size_t size() const { return _meanVar.size(); };
+	size_t size() const { return _meanVar.size(); }
 
 	T sum() const {
 		T sum = 0;
 		for (auto &it : _meanVar) {
 			// check for numeric under- and overflow
-			if (!checkForNumericOverflow_addition(sum, it.sum())) {
-				DEVERROR("Numeric under- or overflow occured!");
-			}
+			DEV_ASSERT(checkForNumericOverflow_addition(sum, it.sum()));
 			sum += it.sum();
 		}
 		return sum;
-	};
+	}
 
 	bool exists(const uint32_t ID) const {
-		if (ID < _meanVar.size())
-			return true;
-		else
-			return false;
-	};
+		return ID < _meanVar.size();
+	}
 
 	const TMeanVar<T> &operator[](const uint32_t ID) {
-		if (!exists(ID)) DEVERROR("No entry with key ", ID, " in TMeanVarVector!");
+		DEV_ASSERT(exists(ID));
+
 		return _meanVar[ID];
-	};
+	}
 };
 	
 }
