@@ -1,7 +1,8 @@
 #ifndef TLOGINT_H_
 #define TLOGINT_H_
 
-#include <cassert>
+#include "coretools/Main/TError.h"
+
 #include <cmath>
 #include <cstdint>
 
@@ -11,14 +12,14 @@ class TLogInt {
 private:		
 	uint8_t _value;
 
-	static uint8_t _linear2log(uint64_t Lin) noexcept {
-		assert(Lin > 0);
+	static uint8_t _linear2log(uint64_t Lin) noexcept(noDebug) {
+		DEBUG_ASSERT(Lin > 0);
 		// Performance improved using C++20 bit>
 		return ceil(std::log2(Lin));
 	}
 
-	static constexpr uint64_t _log2linear(uint8_t Log) noexcept {
-		assert(Log < 64); // overflow
+	static constexpr uint64_t _log2linear(uint8_t Log) noexcept(noDebug) {
+		DEBUG_ASSERT(Log < 64); // overflow
 		return uint64_t(1) << Log;
 	}
 
@@ -27,8 +28,8 @@ private:
 public:
 	// No Constructors, these functions are more clear
 	static TLogInt fromLinear(uint64_t Lin) noexcept { return TLogInt{_linear2log(Lin)}; }
-	static constexpr TLogInt fromLog(uint8_t Log) noexcept {
-		assert(Log < 64);
+	static constexpr TLogInt fromLog(uint8_t Log) noexcept(noDebug) {
+		DEBUG_ASSERT(Log < 64);
 		return TLogInt{Log};
 	}
 	static constexpr TLogInt min() noexcept { return TLogInt{0}; } // linear = 1 !
